@@ -5,13 +5,14 @@
 __author__ = "Mike Schiffman"
 __email__ = "mschiffm@cisco.com"
 __credits__ = "William McVey"
-__date__ = "March 2013"
-__revision__ = "0.11"
+__date__ = "November 2013"
+__revision__ = "0.13"
 __maintainer__ = "Mike Schiffman"
 
 import os
 import sys
 import copy
+import codecs
 import urllib2
 import argparse
 from lxml import etree
@@ -126,10 +127,10 @@ def cvrf_dump(results, strip_ns):
     """
     for key in results:
         if key == "stdout":
-            f = sys.stdout
+            f = codecs.EncodedFile(sys.stdout, input="UTF-8")
         else:
             try:
-                f = open(key, "w")
+                f = codecs.open(key, "w", encoding="UTF-8")
             except IOError as e:
                 sys.exit("{0}: I/O error({1}) \"{2}\": {3}".format(progname, e.errno, key, e.strerror))
         for item in results[key]:
@@ -206,7 +207,8 @@ def post_process_arglist(arg, namespace, valid_args):
     return parsables
 
 
-def main(progname=sys.argv[0]):
+def main(progname = None):
+    progname = progname if progname else os.path.basename(sys.argv[0])
     parser = argparse.ArgumentParser(formatter_class=NonDupBracketFormatter,
                                      description="Validate/parse a CVRF 1.1 document and emit user-specified bits.")
     parser.add_argument("-f", "--file", required="True", action="store",
@@ -248,7 +250,7 @@ def main(progname=sys.argv[0]):
     # First things first: parse the document (to ensure it is well-formed XML) to obtain an ElementTree object
     # to pass to the CVRF validator/parser
     try:
-        cvrf_doc = etree.parse(args.file)
+        cvrf_doc = etree.parse(args.file, etree.XMLParser(encoding="utf-8"))
     except IOError:
         sys.exit("{0}: I/O error: \"{1}\" does not exist".format(progname, args.file))
     except etree.XMLSyntaxError as e:
